package org.vraptor.component;

import java.util.Set;

import org.vraptor.LogicRequest;
import org.vraptor.url.RequestInfo;

/**
 * Component managers are capable of finding and dealing with business
 * components/logics.
 * 
 * @author Guilherme Silveira
 */
public interface ComponentManager {

	/**
	 * Registers a new component
	 * 
	 * @param type
	 *            component class
	 * @throws InvalidComponentException
	 *             invalid component
	 */
	boolean register(String type) throws InvalidComponentException;

	/**
	 * Returns the business component
	 * 
	 * @throws InvalidComponentException
	 *             if there is no component with this name
	 */
	ComponentType getComponent(RequestInfo info) throws ComponentNotFoundException;

	/**
	 * Returns a list with all component classes.
	 * 
	 * @return all components registered
	 */
	Set<ComponentType> getComponents();

	/**
	 * Directly registers a component type.
	 * 
	 * @param type
	 *            the component type
	 */
	void register(ComponentType type);

}
