package org.vraptor.component;

import java.util.Collection;
import java.util.List;
import java.util.Map;

import org.vraptor.LogicRequest;
import org.vraptor.annotations.In;
import org.vraptor.interceptor.InterceptorType;
import org.vraptor.introspector.ReadParameter;
import org.vraptor.reflection.GettingException;
import org.vraptor.reflection.MethodInvocationException;
import org.vraptor.scope.ScopeType;

/**
 * A component wrapper.
 * 
 * @author Guilherme Silveira
 */
public class ComponentWrapper implements ComponentType {

	private final ComponentType type;

	public ComponentWrapper(ComponentType component) {
		this.type = component;
	}

	public List<FieldAnnotation<In>> getInAnnotations() {
		return type.getInAnnotations();
	}

	public List<InterceptorType> getInterceptors() {
		return type.getInterceptors();
	}

	public LogicMethod getLogic(String key) throws LogicNotFoundException {
		return type.getLogic(key);
	}

	public String getName() {
		return type.getName();
	}

	public List<ReadParameter> getReadParameters() {
		return type.getReadParameters();
	}

	public Collection<LogicMethod> getLogics() {
		return type.getLogics();
	}

	public Class getComponentClass() {
		return type.getComponentClass();
	}

	public Object newInstance(LogicRequest request) throws ComponentInstantiationException {
		return type.newInstance(request);
	}

	public ScopeType getScope() {
		return type.getScope();
	}

	public String getKey() {
		return type.getKey();
	}

	public String getDestroyLogicName() {
		return type.getDestroyLogicName();
	}

	public Map<String, Object> getOutjectedValues(Object comp, ScopeType scope) throws GettingException, MethodInvocationException {
		return type.getOutjectedValues(comp, scope);
	}

}
