package org.vraptor.core;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.apache.log4j.Logger;
import org.vraptor.LogicRequest;
import org.vraptor.component.LogicMethod;
import org.vraptor.i18n.JstlWrapper;
import org.vraptor.introspector.Introspector;
import org.vraptor.reflection.SettingException;
import org.vraptor.validator.UnstableValidationException;
import org.vraptor.validator.ValidationErrors;

/**
 * Responsible for validating data.
 * 
 * @author Guilherme Silveira
 */
public class ValidatorEngine {

	private static final Logger LOG = Logger.getLogger(ValidatorEngine.class);

	private static final String BUNDLE_NAME = "messages";

	private static final JstlWrapper JSTL = new JstlWrapper();
	public ValidationErrors validate(LogicMethod method, LogicRequest request, Introspector introspector,
			Object component) throws SettingException, UnstableValidationException {

		// TODO refactor to remove the cast
		Locale locale = JSTL.findLocale((LogicRequest) request);
		ValidationErrors errors = method.validate(component, request, loadBundle(locale));
		return errors;

	}

	private ResourceBundle loadBundle(Locale locale) {
		if (LOG.isDebugEnabled()) {
			LOG.debug("loading resource bundle: " + BUNDLE_NAME + " for locale " + locale);
		}
		try {
			return ResourceBundle.getBundle(BUNDLE_NAME, locale);
		} catch (MissingResourceException ex) {
			LOG.debug("Resource bundle not found: " + BUNDLE_NAME);
			return null;
		}
	}
}
