package org.vraptor.interceptor;

import org.vraptor.Interceptor;
import org.vraptor.LogicException;
import org.vraptor.LogicFlow;
import org.vraptor.LogicRequest;
import org.vraptor.component.ComponentInstantiationException;
import org.vraptor.scope.Context;
import org.vraptor.scope.LogicContext;
import org.vraptor.scope.ScopeType;
import org.vraptor.view.ViewException;

/**
 * Looks up for the component and registers it in the logic context.
 * 
 * @author Guilherme Silveira
 */
public class ComponentLookupInterceptor implements Interceptor {

	public void intercept(LogicFlow flow) throws LogicException, ViewException {
		try {
			LogicRequest request = flow.getLogicRequest();
			LogicContext context = request.getLogicContext();

			String key = flow.getLogicRequest().getComponentType().getKey();

			// TODO: logic scope should be removed! nobody uses and makes code
			// complex
			Context scope = flow.getLogicRequest().getComponentType().getScope().getContext(request);

			Object componentObject;
			if (scope.hasAttribute(key)) {
				componentObject = scope.getAttribute(key);
			} else {
				componentObject = flow.getLogicRequest().getComponentType().newInstance(request);
			}

			scope.setAttribute(key, componentObject);
			context.setComponent(componentObject);

			flow.getLogicRequest().setComponent(componentObject);

			flow.execute();

			// if either logic, request or should be removed
			if (flow.getLogicRequest().getComponentType().getDestroyLogicName().equals(
					request.getRequestInfo().getLogicName())
					|| flow.getLogicRequest().getComponentType().getScope().equals(ScopeType.LOGIC)
					|| flow.getLogicRequest().getComponentType().getScope().equals(ScopeType.REQUEST)) {
				// why remove it from request|logic ?????
				scope.removeAttribute(key);
			}

		} catch (ComponentInstantiationException e) {
			throw new LogicException(e.getMessage(), e);
		}
	}
}
