package org.vraptor.plugin.login;

import java.lang.reflect.Method;

import org.vraptor.Interceptor;
import org.vraptor.LogicException;
import org.vraptor.LogicFlow;
import org.vraptor.view.ViewException;

/**
 * An interceptor which checks for the currentUser attribute in the session. If
 * the user is not in the session, its an invalid request. If the user is in the
 * session and the method doesnt contain the Role annotation, the request is
 * valid. If the user doesnt contain any of the required roles, the request is
 * invalid. If the user contains any one of the required roles, the request is
 * valid. If the request is valid, it forwards to the next interceptor,
 * otherwise it throws an AuthorizationException.
 * 
 * @author Guilherme Silveira
 */
public class AuthorizationInterceptor implements Interceptor {

	public void intercept(LogicFlow flow) throws LogicException, ViewException {

		WebUser user = (WebUser) flow.getLogicRequest().getSessionContext().getAttribute("currentUser");

		Method method = flow.getLogicRequest().getLogicMethod().getMetadata().getMethod();

		boolean ok = false;
		if (user == null) {
			// false
		} else if (!method.isAnnotationPresent(Role.class)) {
			ok = true;
		} else {
			Role role = method.getAnnotation(Role.class);
			String[] roles = role.value();
			for (String r : roles) {
				if (user.hasRole(r)) {
					ok = true;
					break;
				}
			}
		}

		if (ok) {
			flow.execute();
		} else {
			throw new LogicException(new AuthorizationException());
		}

	}

}
