package org.vraptor.url;

import javax.servlet.http.HttpServletRequest;

import org.apache.log4j.Logger;

/**
 * The default url manager translates url data.
 * 
 * @author Guilherme Silveira
 */
public class DefaultURLManager implements URLManager {

	private static final Logger LOG = Logger.getLogger(DefaultURLManager.class);

	public RequestInfo extractInfoFromURL(HttpServletRequest req) throws InvalidURLException {
		String uri = req.getRequestURI();
		// TODO: trace
		if (LOG.isDebugEnabled()) {
			LOG.debug("Requested url (request wrapped): " + uri);
		}

		uri = uri.substring(uri.lastIndexOf('/') + 1);
		if (LOG.isDebugEnabled()) {
			LOG.debug("requested uri: " + uri);
		}

		int firstPosition = uri.indexOf('.');
		if (firstPosition == -1)
			throw new InvalidURLException("Unable to deal with desired url: " + uri);

		int secondPosition = uri.indexOf('.', firstPosition + 1);
		if (secondPosition == -1)
			throw new InvalidURLException("Unable to deal with desired url: " + uri);

		int thirdPosition = uri.indexOf('.', secondPosition + 1);
		String viewType = null;
		if (thirdPosition != -1) {
			viewType = uri.substring(secondPosition + 1, thirdPosition);
		}

		String componentName = uri.substring(0, firstPosition);
		String actionName = uri.substring(firstPosition + 1, secondPosition);
		RequestInfo info = new RequestInfo(componentName, actionName, viewType);

		if (LOG.isDebugEnabled()) {
			LOG.debug("request info extracted: " + info);
		}
		return info;
	}

}
