package org.vraptor.url;

/**
 * Encapsulates the component name and logic name that will be invoked.
 * 
 * @author Paulo Silveira
 * 
 */
public class RequestInfo {

	private final String componentName;

	private final String logicName;

	private final String viewType;

	/**
	 * @param componentName
	 *            the name of the Component to be used
	 * @param logicName
	 *            the logic name form the component that will be invoked
	 */
	public RequestInfo(String componentName, String logicName) {
		this(componentName, logicName, null);
	}

	/**
	 * @param componentName
	 *            the name of the Component to be used
	 * @param logicName
	 *            the logic name form the component that will be invoked
	 * @param viewType
	 *            "json", "xml" or null for normal treatment
	 */
	public RequestInfo(String componentName, String logicName, String viewType) {
		this.componentName = componentName;
		this.logicName = logicName;
		this.viewType = viewType;
	}

	public String getComponentName() {
		return componentName;
	}

	public String getLogicName() {
		return logicName;
	}

	public String getViewType() {
		return viewType;
	}

	public boolean isDefaultView() {
		return viewType == null;
	}
	
	@Override
	public String toString() {
		return String.format("[RequestInfo: %s, %s, %s]", componentName, logicName, viewType);
	}
}
