package org.vraptor.view;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.Map;

import org.apache.log4j.Logger;
import org.vraptor.LogicRequest;
import org.vraptor.annotations.Remotable;
import org.vraptor.component.ComponentType;
import org.vraptor.reflection.GettingException;
import org.vraptor.reflection.MethodInvocationException;
import org.vraptor.remote.OutjectionSerializer;
import org.vraptor.remote.json.JSONSerializer;
import org.vraptor.scope.ScopeType;

/**
 * If it is a remote vie request, like JSON or XML request, render it. If not,
 * delegates to the internal manager.
 * 
 */
public class RemoteViewManager implements ViewManager {

	private static final Logger LOG = Logger.getLogger(RemoteViewManager.class);

	private final ViewManager internalManager;

	public RemoteViewManager(ViewManager viewManager) {
		this.internalManager = viewManager;
	}

	public void directForward(LogicRequest logicRequest, String result, String forwardUrl) throws ViewException {
		internalManager.directForward(logicRequest, result, forwardUrl);
	}

	public void forward(LogicRequest logicRequest, String result) throws ViewException {

		if (!logicRequest.getRequestInfo().isDefaultView()) {

			RemoteView remote = RemoteView.valueOf(logicRequest.getRequestInfo().getViewType().toUpperCase());
			if (LOG.isDebugEnabled()) {
				LOG.debug("delegating redering to remote view " + remote);
			}
			Object comp = logicRequest.getComponent();
			ComponentType type = logicRequest.getComponentType();

			try {
				Map<String, Object> outjected = type.getOutjectedValues(comp, ScopeType.REQUEST);
				Remotable remotable = logicRequest.getLogicMethod().getMetadata().getAnnotation(Remotable.class);
				CharSequence output = remote.newSerializer(remotable.depth()).serialize(outjected);

				PrintWriter writer = logicRequest.getResponse().getWriter();
				writer.append(output);
				writer.flush();
				writer.close();
			} catch (IOException e) {
				throw new ViewException(e);
			} catch (GettingException e) {
				throw new ViewException(e);
			} catch (MethodInvocationException e) {
				throw new ViewException(e);
			}
		} else {
			internalManager.forward(logicRequest, result);
		}
	}

	public void redirect(LogicRequest request, String result) throws ViewException {
		internalManager.redirect(request, result);
	}

}

enum RemoteView {
	AJAX {

		public OutjectionSerializer newSerializer(int depth) {
			return new JSONSerializer(depth);
		}

	},
	XML {
		public OutjectionSerializer newSerializer(int depth) {
			throw new UnsupportedOperationException();
		}

	};
	public abstract OutjectionSerializer newSerializer(int depth);

}