package org.vraptor.webapp;

import org.vraptor.component.ComponentManager;
import org.vraptor.config.ConfigException;
import org.vraptor.converter.ConverterManager;
import org.vraptor.factory.FactoryManager;
import org.vraptor.scope.ApplicationContext;
import org.vraptor.url.URLManager;
import org.vraptor.view.ViewManager;

/**
 * A web application.
 * 
 * @author Guilherme Silveira
 */
public interface WebApplication {

	/**
	 * Returns the url manager
	 * 
	 * @return the url manager
	 */
	URLManager getURLManager();

	/**
	 * Initializes the web application
	 * 
	 * @throws ConfigException
	 * 
	 */
	void init() throws ConfigException;

	/**
	 * Returns the factory manager
	 * 
	 * @return the factory manager
	 * @deprecated
	 */
	FactoryManager getFactoryManager();

	/**
	 * Returns the component manager
	 * 
	 * @return the component manager
	 */
	ComponentManager getComponentManager();

	/**
	 * Returns the view manager
	 * 
	 * @return the view manager
	 */
	ViewManager getViewManager();

	/**
	 * Returns the converter manager
	 * 
	 * @return the converter manager
	 */
	ConverterManager getConverterManager();

	/**
	 * Returns the plugin manager
	 * 
	 * @return the plugin manager
	 */
	PluginManager getPluginManager();

	/**
	 * Returns the application context.
	 * 
	 * @return the application context
	 */
	ApplicationContext getApplicationContext();

	void setViewManager(ViewManager viewManager);
		
}
